@@ -3,7 +3,7 @@
  *	       An alternative for S/KEY's key program.
  *
  *		 Copyright (C) 1995 Kazuhiko Yamamoto
- *		 Copyright (C) 2016 Peter Pentchev <roam@ringlet.net>
+ *		 Copyright (C) 2016, 2018 Peter Pentchev <roam@ringlet.net>
  *
  * This software conforms to the GNU GENERAL PUBLIC LICENSE Version 2.
  *
@@ -15,7 +15,8 @@
 
 #define _GNU_SOURCE
 
-static const char version_message[] = "donkey version 1.0.1 ../../.. Peter Pentchev";
+#define VERSION "1.1.0"
+static const char version_message[] = "donkey version " VERSION " Peter Pentchev";
 
 #include "config.h"
 #include "donkey.h"
@@ -37,6 +38,7 @@ const struct option longopts [] = {
 	{"help",	0, 0, 'h'},
 	{"version",	0, 0, 'v'},
 	{"function", 	1, 0, 'f'},
+	{"features",	0, 0, 256},
 	{0, 0, 0, 0}
 };
 
@@ -51,18 +53,22 @@ const char * const help_message[] = {
  * definition of local functions
  */
 
-static void usage(const char * const progname)
+static void usage(const char * const progname, const bool error)
 {
-    fprintf(stderr, "usage:\t%s [-n num] [-f func] sequence seed\n\t%s -i\n", progname, progname);
+    fprintf(error ? stderr : stdout,
+	"usage:\t%s [-n num] [-f func] sequence seed\n"
+	"\t%s -i\n"
+	"\t%s -h | --help | -v | --version | --features\n",
+	progname, progname, progname);
 }
 
 static void help(const char * const progname)
 {
     const char * const *p = help_message;
 
-    fprintf(stderr, "help: %s\n", progname);
-    usage(progname);
-    while (*p) fprintf(stderr, "%s\n", *p++);
+    printf("help: %s\n", progname);
+    usage(progname, false);
+    while (*p) printf("%s\n", *p++);
 }
 
 static void version(const char * const progname)
@@ -70,6 +76,11 @@ static void version(const char * const progname)
     fprintf(stderr, "version of %s: %s\n", progname, version_message);
 }
 
+static void features(void)
+{
+    puts("Features: donkey=" VERSION);
+}
+
 static const char *stripname(const char * const filename)
 {
     const char * const p = strrchr(filename, FILESEP);
@@ -295,8 +306,11 @@ int main(const int argc, char * const argv[])
 				exit(EXIT_FAILURE);
 			}
 			break;
+        case 256:
+            features();
+            exit(EXIT_SUCCESS);
 		default:
-			usage(progname);
+			usage(progname, true);
 			exit(EXIT_FAILURE);
 		}
 	}
@@ -305,7 +319,7 @@ int main(const int argc, char * const argv[])
 
 	if (iflag) {
 		if (arg_count != 0) {
-			usage(progname);
+			usage(progname, true);
 			exit(EXIT_FAILURE);
 		}
 
@@ -317,7 +331,7 @@ int main(const int argc, char * const argv[])
 	 */
 	
 	if (arg_count != 2) {
-		usage(progname);
+		usage(progname, true);
 		exit(EXIT_FAILURE);
 	}
 
